@@ -431,7 +431,9 @@ champlain_cache_fill_tile (ChamplainCache *self,
   if (priv->popularity_id == 0)
   {
     g_object_ref (self);
-    priv->popularity_id = g_idle_add (inc_popularity, self);
+    priv->popularity_id = g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+                                           inc_popularity, self,
+                                           g_object_unref);
   }
 
 cleanup:
@@ -462,7 +464,7 @@ champlain_cache_tile_is_expired (ChamplainCache *self,
   gboolean validate_cache = FALSE;
 
   g_get_current_time (&now);
-  g_time_val_add (&now, (-24ul * 60ul * 60ul * 1000ul * 1000ul)); // Cache expires 1 day
+  g_time_val_add (&now, (-24ul * 60ul * 60ul * 1000ul * 1000ul * 7ul)); // Cache expires 7 days
   validate_cache = modified_time->tv_sec < now.tv_sec;
 
   return validate_cache;
@@ -479,7 +481,6 @@ inc_popularity (gpointer data)
 
   if (priv->popularity_queue == NULL)
     {
-      g_object_unref (cache);
       priv->popularity_id = 0;
       return FALSE;
     }
